@@ -20,7 +20,7 @@
 #ifndef KGAMETHEMESELECTOR_H
 #define KGAMETHEMESELECTOR_H
 
-#include <QtGui/QWidget>
+#include <QtWidgets/QWidget>
 
 //#include <libkdegames_export.h>
 
@@ -63,14 +63,14 @@ public:
     virtual ~KGameThemeSelector();
 
 private:
-    class KGameThemeSelectorPrivate;
-    KGameThemeSelectorPrivate* const d;
+    KGameThemeSelectorPrivate* const d_ptr;
 
     Q_DISABLE_COPY(KGameThemeSelector)
+    Q_DECLARE_PRIVATE(KGameThemeSelector)
 
-    Q_PRIVATE_SLOT(d, void _k_updatePreview())
-    Q_PRIVATE_SLOT(d, void _k_updateThemeList(const QString&))
-    Q_PRIVATE_SLOT(d, void _k_openKNewStuffDialog())
+    Q_PRIVATE_SLOT(d_func(), void _k_updatePreview())
+    Q_PRIVATE_SLOT(d_func(), void _k_updateThemeList(const QString&))
+    Q_PRIVATE_SLOT(d_func(), void _k_openKNewStuffDialog())
 };
 
 #endif
